@@ -102,7 +102,7 @@ namespace eval ::annotate {
           set too_old 1
         }
         if {$too_old} {
-          cvsfail "You need CVS >= 1.11.1 to do this"
+          cvsfail "You need CVS >= 1.11.1 to do this" $w
           namespace delete [namespace current]
           return
         }
