@@ -3,17 +3,17 @@
 #
 
 #
-# $Id: cvs.tcl,v 1.129 2004/11/15 06:04:24 dorothyr Exp $
+# $Id: cvs.tcl,v 1.131 2005/07/15 21:30:14 dorothyr Exp $
 # 
 # Contains procedures used in interaction with CVS.
 #
 
 proc cvs_notincvs {} {
-  cvsfail "This directory is not in CVS."
+  cvsfail "This directory is not in CVS." .workdir
 }
 
 proc cvs_incvs {} {
-  cvsfail "You can\'t do that here because this directory is already in CVS."
+  cvsfail "You can\'t do that here because this directory is already in CVS." .workdir
 }
 
 #
@@ -74,7 +74,7 @@ proc cvs_sandbox_filetags {mcode filenames} {
   set ret [catch {eval "exec $commandline"} view_this]
   if {$ret} {
     cd $cwd
-    cvsfail $view_this
+    cvsfail $view_this .merge
     gen_log:log T "LEAVE ERROR"
     return $keepers
   }
@@ -117,7 +117,7 @@ proc cvs_remove {args} {
     }
   }
   if {$success == 0} {
-    cvsfail "Remove $file failed"
+    cvsfail "Remove $file failed" .workdir
     return
   }
 
@@ -143,7 +143,7 @@ proc cvs_remove_dir {args} {
   }
   set filelist [join $args]
   if {$filelist == ""} {
-    cvsfail "Please select a directory!"
+    cvsfail "Please select a directory!" .workdir
     return 
   } else {
     set mess "This will remove the contents of these directories:\n\n"
@@ -234,7 +234,7 @@ proc cvs_unedit {args} {
     # Its OK if its locally added
     if {([llength $view_this] > 0) && ![string match "A*" $view_this] } {
       gen_log:log D "$view_this"
-      cvsfail "File $file is not up-to-date"
+      cvsfail "File $file is not up-to-date" .workdir
       gen_log:log T "LEAVE -- cvs unedit failed"
       return
     }
@@ -320,7 +320,7 @@ proc cvs_add_dir {binflag args} {
   }
   set filelist [join $args]
   if {$filelist == ""} {
-    cvsfail "Please select a directory!"
+    cvsfail "Please select a directory!" .workdir
     return 1
   } else {
     set mess "This will recursively add these directories:\n\n"
@@ -445,7 +445,7 @@ proc rem_subdirs { v } {
     foreach file $plainfiles {
       gen_log:log F "DELETE $file"    
       file delete -force -- $file
-      if {[file exists $file]} {cvsfail "Remove $file failed"}
+      if {[file exists $file]} {cvsfail "Remove $file failed" .workdir}
     }
     set commandline "$cvs remove $plainfiles"
     #gen_log:log C "$commandline"
@@ -473,7 +473,7 @@ proc cvs_diff {args} {
 
   set filelist [join $args]
   if {$filelist == ""} {
-    cvsfail "Please select one or more files to compare!"
+    cvsfail "Please select one or more files to compare!" .workdir
   } else {
     foreach file $filelist {
       regsub -all {\$} $file {\$} file
@@ -484,7 +484,7 @@ proc cvs_diff {args} {
   gen_log:log T "LEAVE"
 }
 
-proc cvs_diff_r {rev1 rev2 dir args} {
+proc cvs_diff_r {rev1 rev2 dir parent args} {
 #
 # This diffs a file with the repository, using two revisions or tags.
 #
@@ -494,7 +494,7 @@ proc cvs_diff_r {rev1 rev2 dir args} {
   gen_log:log T "ENTER ($rev1 $rev2 $dir $args)"
 
   if {$rev1 == {} && $rev2 == {}} {
-    cvsfail "Must have at least one revision number or tag for this function!"
+    cvsfail "Must have at least one revision number or tag for this function!" $parent
     return 1
   }
 
@@ -505,7 +505,7 @@ proc cvs_diff_r {rev1 rev2 dir args} {
   foreach file $args {
     set cwd [pwd]
     if {[catch {cd $dir}]} {
-        cvsfail "unable to access $dir"
+        cvsfail "unable to access $dir" $parent
         gen_log:log T "LEAVE unable to access $dir"
         return
     }
@@ -584,7 +584,7 @@ proc cvs_logcanvas {directory files} {
   gen_log:log T "ENTER ($directory $files)"
 
   if {$files == {}} {
-    cvsfail "Please select one or more files!"
+    cvsfail "Please select one or more files!" .workdir
     return
   }
 
@@ -707,7 +707,7 @@ proc cvs_log {args} {
       }
     }
   } else {
-    cvsfail "Unknown log option \"$cvscfg(ldetail)\""
+    cvsfail "Unknown log option \"$cvscfg(ldetail)\"" .workdir
   }
 
   busy_done .workdir.main
@@ -734,7 +734,7 @@ proc cvs_annotate {revision args} {
 
   set filelist [join $args]
   if {$filelist == ""} {
-    cvsfail "Annotate:\nPlease select one or more files !"
+    cvsfail "Annotate:\nPlease select one or more files !" .workdir
     gen_log:log T "LEAVE (Unselected files)"
     return
   }
@@ -801,7 +801,7 @@ proc cvs_commit {revision comment args} {
   append mess "\n\nAre you sure?"
   set commit_output ""
 
-  if {[cvsconfirm $mess] == 1} {
+  if {[cvsconfirm $mess .workdir] != "ok"} {
     return 1
   }
 
@@ -819,13 +819,13 @@ proc cvs_commit {revision comment args} {
     gen_log:log C "$commandline"
     set ret [catch {eval "exec $commandline"} view_this]
     if {$ret} {
-      cvsfail $view_this
+      cvsfail $view_this .workdir
       gen_log:log T "LEAVE ERROR ($view_this)"
       return
     }
   } else {
     if {$comment == ""} {
-      cvsfail "You must enter a comment!"
+      cvsfail "You must enter a comment!" .commit
       return 1
     }
     set v [viewer::new "CVS Commit"]
@@ -857,7 +857,7 @@ proc cvs_tag {tagname force branch update args} {
   }
 
   if {$tagname == ""} {
-    cvsfail "You must enter a tag name!"
+    cvsfail "You must enter a tag name!" .workdir
     return 1
   }
 
@@ -951,7 +951,7 @@ proc cvs_update {tagname normal_binary action_if_no_tag get_all_dirs dir args} {
     }
   }
   append mess "\n\nAre you sure?"
-  if {[cvsconfirm $mess] == 0} {
+  if {[cvsconfirm $mess .workdir] == "ok"} {
     # modified by jo to build the commandline incrementally
     set commandline "$cvs update -P"
     if { $normal_binary == "Binary" } {
@@ -1190,13 +1190,13 @@ proc cvs_checkout { dir cvsroot prune kflag revtag date target mtag1 mtag2 modul
     set mess "This is already a CVS controlled directory.  Are you\
               sure that you want to check out another module in\
               to this directory?"
-    if {[cvsconfirm $mess] == 1} {
+    if {[cvsconfirm $mess .modbrowse] != "ok"} {
       return
     }
   }
 
   set mess "This will check out $module from CVS.\nAre you sure?"
-  if {[cvsconfirm $mess] == 0} {
+  if {[cvsconfirm $mess .modbrowse] == "ok"} {
     if {$revtag != {}} {
       set revtag "-r \"$revtag\""
     }
@@ -1225,7 +1225,7 @@ proc cvs_checkout { dir cvsroot prune kflag revtag date target mtag1 mtag2 modul
   return
 }
 
-proc cvs_filelog {filename} {
+proc cvs_filelog {filename parent} {
 #
 # This looks at the revision log of a file.  It's called from filebrowse.tcl, 
 # so we can't do operations such as merges.
@@ -1242,7 +1242,7 @@ proc cvs_filelog {filename} {
   gen_log:log C "$commandline"
   set ret [cvs_sandbox_runcmd "$commandline" cmd_output]
   if {$ret == $cwd} {
-    cvsfail $cmd_output
+    cvsfail $cmd_output $parent
     cd $cwd
     gen_log:log T "LEAVE -- cvs checkout failed"
     return
@@ -1256,25 +1256,6 @@ proc cvs_filelog {filename} {
   gen_log:log T "LEAVE"
 }
 
-proc rcs_filediff {filename ver1 ver2} {
-#
-# This does a diff of an RCS file within the repository.
-#
-  global cvscfg
-
-  gen_log:log T "ENTER ($dir $cvsroot $kflag $revtag $date $target $module)"
-
-  if {$ver1 == {} || $ver2 == {}} {
-    cvsfail "Must have two revision numbers for this function!"
-    return 1
-  }
-  set command "$cvscfg(tkdiff) -r$ver1 -r$ver2 \"$filename\" &"
-  exec::new $commandline
-  
-  #catch {eval "exec $cvscfg(tkdiff) -r$ver1 -r$ver2 \"$filename\" &"}
-  gen_log:log T "LEAVE"
-}
-
 proc cvs_export { dir cvsroot kflag revtag date target module } {
 #
 # This exports a new module (see man cvs and read about export) into
@@ -1289,13 +1270,13 @@ proc cvs_export { dir cvsroot kflag revtag date target module } {
   if {$incvs} { 
     set mess "This is already a CVS controlled directory.  Are you\
               sure that you want to export a module in to this directory?"
-    if {[cvsconfirm $mess] == 1} {
+    if {[cvsconfirm $mess .modbrowse] != "ok"} {
       return
     }
   }
 
   set mess "This will export $module from CVS.\nAre you sure?"
-  if {[cvsconfirm $mess] == 0} {
+  if {[cvsconfirm $mess .modbrowse] == "ok"} {
     if {$revtag != {}} {
       set revtag "-r \"$revtag\""
     }
@@ -1353,7 +1334,7 @@ proc cvs_patch { cvsroot module difffmt revtagA dateA revtagB dateB outmode outf
     set patch [$e\::output]
     gen_log:log F "OPEN $outfile"
     if {[catch {set fo [open $outfile w]}]} {
-      cvsfail "Cannot open $outfile for writing"
+      cvsfail "Cannot open $outfile for writing" .modbrowse
       return
     }
     puts $fo $patch
@@ -1441,7 +1422,7 @@ proc cvs_merge_conflict {args} {
       # There are conflict markers already, dont update
       ;
     } else {
-      cvsfail "This file does not appear to have a conflict."
+      cvsfail "This file does not appear to have a conflict." .workdir
       return
     }
     # Invoke tkdiff with the proper option for a conflict file
@@ -1457,7 +1438,7 @@ proc cvs_merge_conflict {args} {
   gen_log:log T "LEAVE"
 }
 
-proc cvs_gettaglist {filename} {
+proc cvs_gettaglist {filename parent} {
   global cvs
   global cvscfg
   global cwd
@@ -1471,7 +1452,7 @@ proc cvs_gettaglist {filename} {
   # run a command, possibly creating the sandbox to play in
   set ret [cvs_sandbox_runcmd $commandline cmd_output]
   if {$cwd == $ret} {
-    cvsfail $cmd_output
+    cvsfail $cmd_output $parent
     cd $cwd
     gen_log:log T "LEAVE ERROR ($cmd_output)"
     return $keepers
@@ -1481,7 +1462,7 @@ proc cvs_gettaglist {filename} {
   gen_log:log C "$commandline"
   set ret [catch {eval "exec $commandline"} view_this]
   if {$ret} {
-    cvsfail $view_this
+    cvsfail $view_this $parent
     cd $cwd
     gen_log:log T "LEAVE ERROR"
     return $keepers
@@ -1509,7 +1490,7 @@ proc cvs_release {delflag directory} {
 
   gen_log:log T "ENTER ($directory)"
   if {! [file isdirectory $directory]} {
-    cvsfail "$directory is not a directory"
+    cvsfail "$directory is not a directory" .workdir
     return
   }
 
@@ -1520,7 +1501,7 @@ proc cvs_release {delflag directory} {
     view_output::new "CVS Check" $view_this
     set mess "$directory is not up-to-date."
     append mess "\nRelease anyway?"
-    if {[cvsconfirm $mess] == 1} {
+    if {[cvsconfirm $mess .workdir] != "ok"} {
       return
     }
   }
@@ -1566,7 +1547,7 @@ proc cvs_rtag { cvsroot mcode branch force oldtag newtag } {
   
   gen_log:log T "ENTER ($cvsroot $mcode $branch $force $oldtag $newtag)"
   if {$newtag == ""} {
-    cvsfail "You must enter a tag name!"
+    cvsfail "You must enter a tag name!" .modbrowse
     return 1
   }
 
