@@ -3,7 +3,7 @@
 #
 
 #
-# $Id: dialog.tcl,v 1.35 2004/11/08 04:39:10 dorothyr Exp $
+# $Id: dialog.tcl,v 1.38 2005/07/07 04:18:50 dorothyr Exp $
 #
 # Smallish dialogs - add, tag
 #
@@ -226,7 +226,7 @@ proc ::dialog::FormComplete { ns form_data } {
             ::dialog::FormLayout [namespace current] $form_data
           }
           focus $w.form.f$field.e
-          cvsok "$text may not be blank"
+          cvsok "$text may not be blank" $w.form
           return 0
         }
       }
@@ -290,7 +290,8 @@ proc ::dialog::checkout { cvsroot module {revtag {}} } {
       variable date
       if {$revtag != {} && $date != {}} {
         ::dialog::FormFocus [namespace current] $::dialog::form_checkout "revtag"
-        cvsok "Only one of Revision/Tag and Date may be specified."
+        cvsok "Only one of Revision/Tag and Date may be specified." \
+            $::dialog::form_checkout
         return 0
       }
       return 1
@@ -363,12 +364,14 @@ proc ::dialog::export { cvsroot module {revtag {}} } {
       variable date
       if {$revtag == {} && $date == {}} {
         ::dialog::FormFocus [namespace current] $::dialog::form_checkout "revtag"
-        cvsok "One of Revision/Tag or Date must be specified."
+        cvsok "One of Revision/Tag or Date must be specified." \
+            $::dialog::form_checkout
         return 0
       }
       if {$revtag != {} && $date != {}} {
         ::dialog::FormFocus [namespace current] $::dialog::form_checkout "revtag"
-        cvsok "Only one of Revision/Tag and Date may be specified."
+        cvsok "Only one of Revision/Tag and Date may be specified." \
+            $::dialog::form_checkout
         return 0
       }
       return 1
@@ -566,6 +569,11 @@ proc merge_dialog { from since file {fromtag {}} } {
     set mtag "${toprefix}_${curr_tag}_$today"
     set ftag "${fromprefix}_${fromtag}_$today"
 
+    # I had symbolic tags in mind, but some people are using untagged versions.
+    # Substitute the dots, which are illegal for tagnames.
+    regsub -all {\.} $mtag {-} mtag
+    regsub -all {\.} $ftag {-} ftag
+
     toplevel .merge
     frame .merge.top
 
@@ -762,13 +770,13 @@ proc subtract_dialog {args} {
 
   set filelist [join $args]
   if {$filelist == ""} {
-    cvsfail "Please select some files to delete first!"
+    cvsfail "Please select some files to delete first!" .workdir
     return
   }
 
   foreach f $filelist {
     if {[file isdirectory $f]} {
-      cvsfail "$f is a directory. Try \"Remove Recursively\" instead"
+      cvsfail "$f is a directory. Try \"Remove Recursively\" instead" .workdir
       return
     }
   }
@@ -819,7 +827,7 @@ proc edit_dialog {args} {
   }
 
   if {$args == "."} {
-    cvsfail "Please select some files to edit first!"
+    cvsfail "Please select some files to edit first!" .workdir
     return
   }
   toplevel .editflag
@@ -869,7 +877,7 @@ proc unedit_dialog {args} {
   }
 
   if {$args == "."} {
-    cvsfail "Please select some files to unedit first!"
+    cvsfail "Please select some files to unedit first!" .workdir
     return
   }
   toplevel .uneditflag
@@ -1163,7 +1171,8 @@ proc update_with_options {} {
        {$cvsglb(norm_bin)} {$cvsglb(action_notag)} {$cvsglb(get_all_dirs)} \
        {$dirname} [workdir_list_files]"
   } else {
-    cvsfail "Internal TkCVS error.\ntagmode_selection $cvsglb(tagmode_selection)."
+    cvsfail "Internal TkCVS error.\ntagmode_selection $cvsglb(tagmode_selection)." \
+        .workdir
   }
   gen_log:log T "LEAVE"
 }
@@ -1237,7 +1246,7 @@ proc subtractdir_dialog {args} {
 
   set filelist [join $args]
   if {$filelist == ""} {
-    cvsfail "Please select some directories to remove first!"
+    cvsfail "Please select some directories to remove first!" .workdir
     return
   }
 
@@ -1361,4 +1370,3 @@ proc release_dialog { args } {
 
   gen_log:log T "LEAVE"
 }
-
