@@ -94,7 +94,7 @@ namespace eval ::exec {
 
             if {$errmsg == ""} {set errmsg "$command exited status $status"}
             if {[string length $errmsg] < 256} {
-               cvsfail $errmsg
+               cvsfail $errmsg .
             }
             # If we don't pop up an error dialog, let's at least try to show
             # what happened in the viewer window, if there is one
@@ -114,6 +114,7 @@ namespace eval ::exec {
             gen_log:log D "  ExecDone $ExecDone"
             
           }
+          catch {close $procerr}
           if {$viewer != {}} {
             pack forget $v_w.stop
             pack $v_w.close -in $v_w.bottom -side right -ipadx 15
@@ -519,6 +520,7 @@ proc save_viewcontents {w} {
     tk_getSaveFile -title "Save Results Summary" \
        -initialdir "." \
        -filetypes $types \
+       -parent $w \
   ]  
   if {$savfile == ""} {
     return
