@@ -3,7 +3,7 @@
 #
 
 #
-# $Id: filebrowse.tcl,v 1.18 2003/10/17 07:30:11 dorothyr Exp $
+# $Id: filebrowse.tcl,v 1.20 2005/06/26 06:15:29 dorothyr Exp $
 #
 # Sets up a dialog to browse the contents of a module.
 #
@@ -18,12 +18,12 @@ proc browse_files {module} {
   static {browser 0}
 
   if {$module == ""} {
-    cvsfail "Please select a module!"
+    cvsfail "Please select a module!" .modbrowse
     return
   }
   #gen_log:log D "[array names modval]"
   if {[lsearch -exact [array names modval] $module] < 0} {
-    cvsfail "$module is not a CVS module"
+    cvsfail "$module is not a CVS module" .modbrowse
     return
   }
 
@@ -31,7 +31,7 @@ proc browse_files {module} {
   find_filenames $module
 
   if {! [info exists filenames($module)]} {
-    cvsfail "There are no files in this module!"
+    cvsfail "There are no files in this module!" .modbrowse
     return
   }
 
@@ -69,11 +69,11 @@ proc browse_files {module} {
   }
 
   button $filebrowse.view -image Fileview \
-    -command "fileview $filebrowse $module"
+    -command "module_fileview $filebrowse $module"
   button $filebrowse.log -image Branches \
-    -command "filelog $filebrowse.list $module"
+    -command "module_filelog $filebrowse $module"
   button $filebrowse.tag -image Tags \
-    -command "tagview $filebrowse $module"
+    -command "module_tagview $filebrowse $module"
   button $filebrowse.quit -text "Close" \
     -padx 0 -pady 0 \
     -command "destroy $filebrowse"
@@ -158,18 +158,19 @@ proc filepath {module filename} {
   return $file
 }
 
-proc filelog {listname module} {
+proc module_filelog {toplevelname module} {
   # Open the logbrowser from the file list
-  gen_log:log T "ENTER ($listname $module)"
+  gen_log:log T "ENTER ($toplevelname $module)"
+  set listname $toplevelname.list
   foreach item [$listname curselection] {
     set v [$listname get $item]
     set f [filepath $module $v]
-    cvs_filelog "$f"
+    cvs_filelog "$f" $toplevelname
   }
   gen_log:log T "LEAVE"
 }
 
-proc fileview {toplevelname module} {
+proc module_fileview {toplevelname module} {
   # View a file from the file list
   gen_log:log T "ENTER ($toplevelname $module)"
   set listname $toplevelname.list
@@ -181,14 +182,14 @@ proc fileview {toplevelname module} {
   gen_log:log T "LEAVE"
 }
 
-proc tagview {toplevelname module} {
+proc module_tagview {toplevelname module} {
   # List the tags of a file from the filelist
   gen_log:log T "ENTER ($toplevelname $module)"
   set listname $toplevelname.list
   foreach item [$listname curselection] {
     set v [$listname get $item]
     set f [filepath $module $v]
-    view_output::new "$f Tags" [cvs_gettaglist "$f"]
+    view_output::new "$f Tags" [cvs_gettaglist "$f" $toplevelname]
   }
   gen_log:log T "LEAVE"
 }
