@@ -5,6 +5,7 @@
 proc gen_log:init {} {
   global cvscfg
   global cvsglb
+  global tcl_platform
 
   toplevel .trace
   wm protocol .trace WM_DELETE_WINDOW { .trace.close invoke }
@@ -52,7 +53,9 @@ proc gen_log:init {} {
   #bind_show .trace.text
 
   wm title .trace "TkCVS Trace"
-  wm iconbitmap .trace @$cvscfg(bitmapdir)/trace.xbm
+  if {$tcl_platform(platform) != "windows"} {
+    wm iconbitmap .trace @$cvscfg(bitmapdir)/trace.xbm
+  }
 }
 
 proc gen_log:log { class string } { 
@@ -68,8 +71,11 @@ proc gen_log:log { class string } {
       set callerid [lindex [info level $callerlevel] 0]
     }
     .trace.text insert end [format "\[%s] %s\n" $callerid "$string"] tag$class
+    set overflow [expr {[.trace.text index end] - $cvscfg(trace_savelines)}]
+    if { $overflow > 10 } {
+       .trace.text delete 0.0 $overflow
+    }
     .trace.text yview end
-    #update idletasks
   }
 }
 
