@@ -3,7 +3,7 @@
 #
 
 #
-# $Id: help.tcl,v 1.56 2004/11/09 05:42:53 dorothyr Exp $
+# $Id: help.tcl,v 1.60 2005/07/19 18:16:22 dorothyr Exp $
 #
 # Help procedures and help data.
 #
@@ -32,7 +32,7 @@ proc aboutbox {} {
   frame .about.top
 
   message .about.top.msg1 -width 400 -justify c \
-    -text "\nTkCVS Version 7.2.2\n" -font $cvscfg(guifont)
+    -text "\nTkCVS Version 7.2.4\n" -font $cvscfg(guifont)
   pack .about.top -side top -expand 1 -fill both
 
   image create photo Tclfish -format gif -file \
@@ -66,7 +66,7 @@ proc aboutbox {} {
   pack .about.down.ok
 }
 
-proc wish_version {} {
+proc wish_version {{parent {.}}} {
   global tk_version
 
   set version $tk_version
@@ -75,10 +75,10 @@ proc wish_version {} {
   set about_string "$whichwish\n\n"
   append about_string "Tk version  $version"
 
-  tk_dialog .aboutwish "About Wish" \
-    $about_string \
-    "" \
-    0 "OK"
+  tk_messageBox -title "About Wish" \
+    -message $about_string \
+    -parent $parent \
+    -type ok
 }
 
 ######################################################################
