@@ -3,7 +3,7 @@
 #
 
 #
-# $Id: import.tcl,v 1.46 2004/11/15 06:08:35 dorothyr Exp $
+# $Id: import.tcl,v 1.47 2005/06/06 03:03:22 dorothyr Exp $
 #
 # Adds a new document to the repository.
 #
@@ -17,7 +17,7 @@ proc import_run {} {
   
   cvsroot_check [pwd]
   if {$incvs} {
-    cvsok "This directory is already in CVS.\nCan\'t import here!"
+    cvsok "This directory is already in CVS.\nCan\'t import here!" .import
     gen_log:log T "LEAVE"
     return
   }
@@ -110,11 +110,11 @@ proc do_import {} {
 
   # Error checks
   if { $cvsglb(newcode) == "" } {
-    cvsok "You must type in a new module name."
+    cvsok "You must type in a new module name." .import
     return 1
   }
   if { $cvsglb(newdir) == "" } {
-    cvsok "You must type in a new module path directory."
+    cvsok "You must type in a new module path directory." .import
     return 1
   }
   
@@ -125,7 +125,7 @@ proc do_import {} {
   # Make sure it isn't a duplicate key
   foreach {key value} [array get modval] {
      if { $cvsglb(newcode) == $key } {
-        cvsok "$cvsglb(newcode) is not a new Module"
+        cvsok "$cvsglb(newcode) is not a new Module" .import
 	return 1
      }
   }
@@ -219,7 +219,7 @@ proc do_import {} {
      set ckmoddir [file join [file dirname $cwd] $cvsglb(newcode)]
   }  
   if { [catch "cd $ckmoddir" err]} {
-    cvsok "$err"
+    cvsok "$err" .import
   } else {
     gen_log:log F "CD [pwd]"
   }
