@@ -19,11 +19,6 @@ proc import2_run {} {
   gen_log:log T "ENTER"
 
   cvsroot_check [pwd]
-#  if {$incvs} {
-#    cvsok "This directory is already in CVS.\nCan\'t import here!"
-#    gen_log:log T "LEAVE"
-#    return
-#  }
 
   if {[winfo exists .import2]} {
     wm deiconify .import2
@@ -112,19 +107,19 @@ proc do_import2 {} {
 
   # Error checks
   if { $cvsglb(existmodule) == "" } {
-    cvsok "You must select an existing module from the repository."
+    cvsok "You must select an existing module from the repository." .import2
     raise .import2
     grab set .import2
     return 1
   }
   if { $cvsglb(newdir) == "" } {
-    cvsok "You must select an existing module from the repository."
+    cvsok "You must select an existing module from the repository." .import2
     raise .import2
     grab set .import2
     return 1
   }
   if { $cvsglb(newvers) == "" } {
-    cvsok "You must type in a version number."
+    cvsok "You must type in a version number." .import2
     raise .import2
     grab set .import2
     return 1
@@ -266,7 +261,7 @@ proc import_wait { } {
   }
   
   if { $module_in_root == 0 && $module_in_dir == 0 } {
-     cvsok "$importselect is not an existing module"
+     cvsok "$importselect is not an existing module" .import2
      set cvsglb(existmodule) ""
      set cvsglb(newdir) ""
      raise .import2
@@ -274,7 +269,7 @@ proc import_wait { } {
   }
   
   if { $module_in_root > 0 && $module_in_dir > 0 } {
-     cvsok "Error: $importselect found in more that one module."
+     cvsok "Error: $importselect found in more that one module." .import2
      set cvsglb(existmodule) ""
      set cvsglb(newdir) ""
      raise .import2
