@@ -3,7 +3,7 @@
 #
 
 #
-# $Id: logcanvas.tcl,v 1.72 2004/11/08 04:58:56 dorothyr Exp $
+# $Id: logcanvas.tcl,v 1.74 2005/06/26 06:15:29 dorothyr Exp $
 #
 # Contains procedures used for the log canvas for tkCVS.
 #
@@ -38,8 +38,10 @@ namespace eval ::logcanvas {
     }
     if {![info exists current_tagname]} {
       set current_tagname ""
-      cvsroot_check $cwd
-      read_cvs_dir [file join $cwd CVS]
+      if {$localfile != "no file"} {
+        cvsroot_check $cwd
+        read_cvs_dir [file join $cwd CVS]
+      }
     }
 
     namespace eval $my_idx {
@@ -103,7 +105,7 @@ namespace eval ::logcanvas {
         catch { unset branchrevs }
         set cwd [pwd]
         if {[catch {cd $directory}]} {
-          cvsfail "unable to access $directory"
+          cvsfail "unable to access $directory" $logcanvas
           gen_log:log T "LEAVE unable to access $directory"
           return
         }
@@ -468,7 +470,7 @@ namespace eval ::logcanvas {
         } else {
           $logcanvas.up.rev${AorB}_rvers configure -text $rev
         }
-        if {$rev != {}} {
+        if {$rev != {} && [info exists revwho($rev)]} {
           $logcanvas.up.rev${AorB}_rwho configure -text $revwho($rev)
           $logcanvas.up.rev${AorB}_rdate configure -text\
               "$revdate($rev) $revtime($rev)"
@@ -1572,7 +1574,7 @@ namespace eval ::logcanvas {
       button $logcanvas.diff -image Diff \
         -command [namespace code {
                  cvs_diff_r [$logcanvas.up.revA_rvers cget -text] \
-                   [$logcanvas.up.revB_rvers cget -text] $cwd $filename
+                   [$logcanvas.up.revB_rvers cget -text] $cwd $logcanvas $filename
                }]
       button $logcanvas.join -image Mergebranch \
         -command [namespace code {
@@ -1631,7 +1633,6 @@ namespace eval ::logcanvas {
         -command [namespace code {
                  cvs_fileview_checkout [$logcanvas.up.revA_rvers cget -text] $filename
                }]
-        $logcanvas.diff configure -state disabled
         $logcanvas.join configure -state disabled
         $logcanvas.annotate configure \
         -command [namespace code {
