@@ -2,7 +2,7 @@
 # TCL Library for TkCVS
 
 #
-# $Id: merge.tcl,v 1.19 2004/11/15 06:08:35 dorothyr Exp $
+# $Id: merge.tcl,v 1.20 2005/06/06 03:03:40 dorothyr Exp $
 #
 # Modifications by Eugene Lee 10/16/03 
 # 1. .merge window made more robust so user cannot key in incorrect data.
@@ -24,7 +24,7 @@ proc merge_run {mcode} {
   gen_log:log T "ENTER ($mcode)"
 
   if {$mcode == ""} {
-    cvsfail "Please select a module!"
+    cvsfail "Please select a module!" .modbrowse
     gen_log:log T "LEAVE"
     return
   }
@@ -122,7 +122,7 @@ proc merge_run {mcode} {
   button .merge.ok -text "OK" \
     -command {
       if { $venselect_mcode == "" } {
-         cvsfail "Please select a Vendor"
+         cvsfail "Please select a Vendor" .merge
          return
       }
       catch do_merge results
@@ -251,12 +251,12 @@ proc do_merge {} {
   gen_log:log T "ENTER"
   set merge(3rd_party) $venselect_mcode
   if { $merge(3rd_party) == "" } {
-    cvsfail "Vendor Module not specified"
+    cvsfail "Vendor Module not specified" .merge
     return err
   }
 
   if { $merge(from) == "" || $merge(to) == "" } {
-    cvsfail "not all entries filled"
+    cvsfail "not all entries filled" .merge
     return err
   }
   
@@ -273,7 +273,7 @@ proc do_merge {} {
      set tmpdir [glob -nocomplain $modbrowse_module]
      if { $tmpdir == "" } {
         cvsfail "You must invoke the merge command from the checked out 
-directory of $modbrowse_module or one above it"
+directory of $modbrowse_module or one above it" .merge
         return
      }
      set dir4merge [file join [pwd] $tmpdir]
@@ -282,7 +282,7 @@ directory of $modbrowse_module or one above it"
   set mess "This will merge differences between $merge(from) and"
   append mess " $merge(to) of $merge(3rd_party) into $modbrowse_module"
   append mess "\n\n Are you sure?"
-  if {[cvsconfirm $mess] == 1} {
+  if {[cvsconfirm $mess .merge] == 1} {
     return
   }
   # The CVS directory in the checked out $modbrowse_module are associated with
@@ -462,7 +462,7 @@ proc merge_taglist {files} {
   set ret [catch {eval "exec $commandline"} view_this]
   gen_log:log "C" "$view_this"
   if {$ret} {
-    cvsfail $view_this
+    cvsfail $view_this .merge
     gen_log:log T "LEAVE ERROR"
     return $keepers
   }
