@@ -1,5 +1,5 @@
 #
-# $Id: modbrowse.tcl,v 1.51 2004/03/12 07:37:05 dorothyr Exp $
+# $Id: modbrowse.tcl,v 1.53 2005/07/07 04:18:51 dorothyr Exp $
 #
 # Set up a check out dialog.
 #
@@ -315,17 +315,14 @@ proc modbrowse_run {} {
   global cvs
   global cmd
 
-  if { $cvscfg(cvsroot) == "" } {
-    cvsfail "I don't know what \$CVSROOT is!"
-    return
-  }
-
   if {[info exists cmd(cvs_co)]} {
     catch {$cmd(cvs_co)\::abort}
     unset cmd(cvs_co)
   }
 
-  set cmd(cvs_co) [exec::new "$cvs -d $cvscfg(cvsroot) checkout -p CVSROOT/modules"]
+  if { $cvscfg(cvsroot) != "" } {
+    set cmd(cvs_co) [exec::new "$cvs -d $cvscfg(cvsroot) checkout -p CVSROOT/modules"]
+  }
 
   set modbrowse_module ""
 
@@ -343,7 +340,9 @@ proc modbrowse_run {} {
   wm deiconify .modbrowse
   raise .modbrowse
 
-  parse_modules [$cmd(cvs_co)\::output]
+  if {[info exists cmd(cvs_co)]} {
+    parse_modules [$cmd(cvs_co)\::output]
+  }
   catch {unset cmd(cvs_co)}
 
   # Populate the tree
@@ -557,7 +556,7 @@ proc module_changedir {new_dir} {
     }
   } else {
     set cwd [pwd]
-    cvsfail "Directory $new_dir doesn\'t exist!"
+    cvsfail "Directory $new_dir doesn\'t exist!" .modbrowse
   }
   gen_log:log T "LEAVE"
 }
