@@ -2,7 +2,7 @@
 #
 # Copyright (C) 1997,1998 D. Richard Hipp
 #
-# $Revision: 1.17 $
+# $Revision: 1.18 $
 #
 
 #
@@ -106,11 +106,11 @@ proc ModTree:newitem {w v name title args} {
   set n [file tail $v]
 
   if {![info exists Tree($w:$dir:open)]} {
-    cvsfail "parent item \"$dir\" is missing"
+    cvsfail "parent item \"$dir\" is missing" .modbrowse
   }
   set i [lsearch -exact $Tree($w:$dir:children) $n]
   if {$i>=0} {
-    cvsfail "item \"$v\" already exists"
+    cvsfail "item \"$v\" already exists" .modbrowse
   }
   lappend Tree($w:$dir:children) $n
   set Tree($w:$dir:children) [lsort $Tree($w:$dir:children)]
