@@ -3,7 +3,7 @@
 #
 
 #
-# $Id: reports.tcl,v 1.24 2002/06/04 06:01:58 dorothyr Exp $
+# $Id: reports.tcl,v 1.25 2004/11/15 06:19:40 dorothyr Exp $
 #
 # Procedures for CVS reports.
 #
@@ -109,12 +109,14 @@ proc viewer_setup { } {
   entry .viewer.bottom.entry -width 20 -textvariable cvsglb(searchstr)
   bind .viewer.bottom.entry <Return> \
       "search_textwidget .viewer.text"
+  button .viewer.bottom.save -text "Save to File" -command "save_viewcontents $w"
 
   pack .viewer.bottom -side bottom -fill x
   pack .viewer.scroll -side right -fill y
   pack .viewer.text -fill both -expand 1
   pack .viewer.bottom.srchbtn -side left
   pack .viewer.bottom.entry -side left
+  pack .viewer.bottom.save -side left -padx 25
   pack .viewer.bottom.close -side right -ipadx 15
 
   wm withdraw .viewer
