@@ -3,7 +3,7 @@
 #
 
 #
-# $Id: workdir.tcl,v 1.141 2004/11/08 04:39:10 dorothyr Exp $
+# $Id: workdir.tcl,v 1.144 2005/07/15 21:30:17 dorothyr Exp $
 #
 # Current working directory display.  Handles all of the functions
 # concerned with navigating about the current directory on the main
@@ -551,7 +551,7 @@ proc workdir_menus {} {
       .workdir.menubar.goto add command -label "Delete Bookmark" \
          -command delete_bookmark_dialog
       .workdir.menubar.goto add separator
-      foreach mark [array names bookmarks] {
+      foreach mark [lsort [array names bookmarks]] {
         .workdir.menubar.goto add command -label "$mark" \
            -command "change_dir \"$mark\""
       }
@@ -591,7 +591,7 @@ proc menu_std_help { w } {
   $w.help add command -label "About CVS" -underline 6 \
      -command cvs_version
   $w.help add command -label "About Wish" -underline 6 \
-     -command wish_version
+     -command "wish_version [winfo parent $w]"
   $w.help add separator
   $w.help add command -label "Current Directory Display" \
      -command current_directory
@@ -692,7 +692,7 @@ proc workdir_edit_file {args} {
         gen_log:log C "$commandline"
         eval "exec $commandline"
       } else {
-        cvsfail "$file is not a plain file"
+        cvsfail "$file is not a plain file" .workdir
       }
     }
   }
@@ -707,7 +707,7 @@ proc workdir_view_file {args} {
 
   set filelist [join $args]
   if {$filelist == ""} {
-    cvsfail "Please select some files to view first!"
+    cvsfail "Please select some files to view first!" .workdir
     return
   }
 
@@ -724,7 +724,7 @@ proc workdir_view_file {args} {
       }
       view_output::new "$file" $filelog
     } else {
-      cvsfail "$file is not a plain file"
+      cvsfail "$file is not a plain file" .workdir
     }
   }
   gen_log:log T "LEAVE"
@@ -763,7 +763,7 @@ proc delete_bookmark_dialog { } {
    listbox $mname.lbx -selectmode multiple \
      -font $cvscfg(listboxfont) -width $maxlbl
    pack $mname.lbx -ipadx 10 -ipady 10 -expand y -fill both
-   foreach mark [array names bookmarks] {
+   foreach mark [lsort [array names bookmarks]] {
      $mname.lbx insert end $mark
    }
    frame $mname.buttons
@@ -802,7 +802,7 @@ proc change_dir {new_dir} {
   gen_log:log T "ENTER ($new_dir)"
   if {![file exists $new_dir]} {
     set cwd [pwd]
-    cvsfail "Directory $new_dir doesn\'t exist!"
+    cvsfail "Directory $new_dir doesn\'t exist!" .workdir
     return
   }
   set cwd $new_dir
@@ -1221,10 +1221,10 @@ proc read_cvs_dir {dirname} {
         gen_log:log D "  BRANCH TAG $current_tagname"
       }
     } else {
-      cvsfail "Repository file not found in $dirname"
+      cvsfail "Repository file not found in $dirname" .workdir
     }
   } else {
-    cvsfail "$dirname is not a directory"
+    cvsfail "$dirname is not a directory" .workdir
   }
   gen_log:log T "LEAVE"
 }
@@ -1253,7 +1253,7 @@ proc workdir_cleanup {} {
     }
   } else {
     gen_log:log F "No files to delete"
-    cvsok "Nothing matched $cvscfg(clean_these)"
+    cvsok "Nothing matched $cvscfg(clean_these)" .workdir
     return
   }
   setup_dir
@@ -1267,7 +1267,7 @@ proc workdir_delete_file {args} {
 
   set filelist [join $args]
   if {$filelist == ""} {
-    cvsfail "Please select some files to delete first!"
+    cvsfail "Please select some files to delete first!" .workdir
     return
   }
 
@@ -1299,7 +1299,7 @@ proc are_you_sure {mess args} {
       }
     }
     append mess "\nAre you sure?"
-    if {[cvsconfirm $mess] == 1} {
+    if {[cvsconfirm $mess .workdir] != "ok"} {
       gen_log:log T "LEAVE 0"
       return 0
     }
@@ -1330,7 +1330,7 @@ proc workdir_print_file {args} {
 
   set filelist [join $args]
   if {$filelist == ""} {
-    cvsfail "Please select some files to print first!"
+    cvsfail "Please select some files to print first!" .workdir
     return
   }
 
@@ -1340,7 +1340,7 @@ proc workdir_print_file {args} {
   }
   append mess "\nUsing $cvscfg(print_cmd)\n"
   append mess "\nAre you sure?"
-  if {[cvsconfirm $mess] == 0} {
+  if {[cvsconfirm $mess .workdir] == "ok"} {
     set final_result ""
     foreach file $filelist {
       gen_log:log C "$cvscfg(print_cmd) \"$file\""
@@ -1394,7 +1394,7 @@ proc cvsroot_check { dir } {
 proc nop {} {}
 
 proc disabled {} {
-  cvsok "Command disabled."
+  cvsok "Command disabled." .workdir
 }
 
 proc isCmDirectory { file } {
@@ -1564,7 +1564,7 @@ proc save_options { } {
 
   gen_log:log F "OPEN $optfile"
   if {[catch {set fo [open $optfile w]}]} {
-    cvsfail "Cannot open $optfile for writing"
+    cvsfail "Cannot open $optfile for writing" .workdir
     return
   }
   gen_log:log F "OPEN $bakfile"
@@ -1628,7 +1628,7 @@ proc save_options { } {
         }
       }
     }
-    foreach mark [array names bookmarks] {
+    foreach mark [lsort [array names bookmarks]] {
       gen_log:log D "Adding bookmark \"$mark\""
       puts $fo "set \"bookmarks($mark)\" t"
     }
